(contributing_guide)=
# Contributing to ArviZ
As a scientific, community-driven, open source software project,
ArviZ welcomes contributions from interested individuals or groups.
These guidelines are provided to give potential contributors information
to make their contributions compliant with the conventions of the ArviZ project,
and maximize the probability of such contributions to be merged as quickly
and efficiently as possible.

Even though contributing code or documentation by sending pull requests on
the main [ArviZ GitHub repository](https://github.com/arviz-devs/arviz) is the most common way of contributing and
therefore this guide dedicates many resources to these, ArviZ welcomes any kind of contribution.
As a clear proof, you can become a core contributor and participate in
[ArviZ governance](https://github.com/arviz-devs/arviz/blob/main/GOVERNANCE.md)
without having contributed code to ArviZ.
All contributions to ArviZ, either on its codebase, its documentation,
or its community are valuable and we really appreciate your help.

:::{tip}
Contact us on [Gitter](https://gitter.im/arviz-devs/community) if you want to
contribute to the project but you are not sure where you can contribute or how to start.
:::

Below we list some examples of contributions that might serve as inspiration.

* [Submitting issues](https://github.com/arviz-devs/arviz/issues/new/choose) related to bugs or desired enhancements. Check the details at {doc}`issue_reports`.
* Fixing outstanding [issues](https://github.com/arviz-devs/arviz/issues) (bugs) with the existing codebase. They range from low-level software bugs to higher-level design problems.
* Contributing or improving the [documentation](https://arviz-devs.github.io/arviz/) (`docs`) or examples (`arviz/examples`).
* Help users submitting issues by making sure their issue is clear and/or providing temporal
  workarounds for them. Check the details at {ref}`issue_triaging`
* Review Pull Requests ensuring contributions are well tested and documented, that documentation
  renders correctly and has no typos or mistakes. Check the details at {ref}`review_prs`
* Adding new or improved functionality to the existing codebase.

Further information on how to contribute to ArviZ can be found on these specific pages:

```{toctree}
:maxdepth: 2
:caption: Contribution types overview

issue_reports
issue_triaging
outreach
review_prs
contributing_prs
```

:::{toctree}
:hidden:
:caption: Tutorials

pr_tutorial
:::

:::{toctree}
:hidden:
:caption: How-to guides

sphinx_doc_build
running_benchmarks
:::

:::{toctree}
:hidden:
:caption: Reference

pr_checklist
architecture
content_structure
docstrings
syntax_guide
developing_in_docker
:::

:::{toctree}
:hidden:
:caption: In depth explanations

doc_toolchain
diataxis_for_arviz
plotting_backends
:::
